@@ -2,15 +2,12 @@ package A::B;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.01';
-
-sub get_orf {
-  print "get_orf";
-
+our $VERSION = '0.03';
+sub aa {
+  return "aa";
 }
-
-sub tt {
-  print "ttt";
+sub bb {
+return 1;
 }
 
 1;
